@@ -372,11 +372,13 @@ class HathiPreservation(models.Model):
                 volume_matcher = r'v\.\s?(\d+(?:\-?\d+)?)'
                 no_matcher = r'no\.\s?(\d+(?:\-?\d+)?)'
                 year_matcher = r'\d{4}'
+                issn_matcher = r'[0-9][0-9][0-9][0-9][-][0-9][0-9][0-9][X0-9]'
 
                 for row in csv_reader:
                     try:
                         vols = row[4]
                         issn = row[9]
+                        issns = []
                         title = row[11]
                         publishing_info = row[12]
                         date = row[16]
@@ -384,10 +386,18 @@ class HathiPreservation(models.Model):
                         unknown_format = False
 
                         # check if it's an ISSN
-                        logging.info('ISSN: {}'.format(issn))
+                        # logging.info('ISSN: {}'.format(issn))
+
+                        # Sometimes we have formats like this for ISSN:
+                        # 1938-1603 (online),0022-1864
+                        issn_matches = re.findall(issn_matcher, issn)
+
+                        if issn_matches:
+                            for match in issn_matches:
+                                issns.append(match)
 
                         # if it's a serial, try to parse the vols
-                        if bf == 'SE' and issn and vols:
+                        if bf == 'SE' and len(issn) > 0 and vols:
                             matches = re.findall(volume_matcher, vols)
 
                             if matches:
@@ -413,11 +423,12 @@ class HathiPreservation(models.Model):
                                 if title.endswith('.'):
                                     title = title[:-1]
 
-                                HathiPreservation.objects.create(
-                                    issn=issn,
-                                    title=title,
-                                    preserved_volumes=vols
-                                )
+                                for issn_no in issn:
+                                    HathiPreservation.objects.create(
+                                        issn=issn_no,
+                                        title=title,
+                                        preserved_volumes=vols
+                                    )
 
                                 logging.info(f'Added {title} to '
                                              f'{HathiPreservation.name()} data')
